# FiscalSim US

| | |
| --- | --- |
| Org | [![CGO cataloged](https://img.shields.io/badge/CGO-catalogued-9cf)](https://github.com/TheCGO) [![OS License: AGPL-3.0](https://img.shields.io/badge/OS%20License-AGPL%203.0-yellow)](https://github.com/TheCGO/fiscalsim-us/blob/main/LICENSE) |
| Package | [![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-31013/) [![Python 3.11](https://img.shields.io/badge/python-3.11-blue.svg)](https://www.python.org/downloads/release/python-3119/) [![PyPI Latest Release](https://img.shields.io/pypi/v/fiscalsim-us.svg)](https://pypi.org/project/fiscalsim-us/) [![PyPI Downloads](https://img.shields.io/pypi/dm/fiscalsim-us.svg?label=PyPI%20downloads)](https://pypi.org/project/fiscalsim-us/) |
| Testing | ![example event parameter](https://github.com/TheCGO/fiscalsim-us/actions/workflows/build_and_test.yml/badge.svg?branch=main) ![example event parameter](https://github.com/TheCGO/fiscalsim-us/actions/workflows/deploy_docs.yml/badge.svg?branch=main) ![example event parameter](https://github.com/TheCGO/fiscalsim-us/actions/workflows/check_format.yml/badge.svg?branch=main) [![Codecov](https://codecov.io/gh/TheCGO/fiscalsim-us/branch/main/graph/badge.svg)](https://codecov.io/gh/TheCGO/fiscalsim-us) |


FiscalSim US is an open source microsimulation model of the US federal and state household tax and benefit system. It is supported and maintained by [The Center for Growth and Opportunity at Utah State University (CGO)](https://www.thecgo.org/). Much of the original federal tax and benefit code and some of the state tax logic was developed by [PolicyEngine](https://policyengine.org/), with which CGO originally had a partnership. Their US model is at [https://github.com/PolicyEngine/policyengine-us](https://github.com/PolicyEngine/policyengine-us).

Documentation for the `FiscalSim-US` model is available online at https://thecgo.github.io/fiscalsim-us. This documentation describes how to install the model, use the model, use the web application for the model, example simulations, details of the types of objects and architecture of the model, and example simulations and capabilities.

We welcome help with updating and improving the `FiscalSim-US` code and correcting errors. You can read the Contributor Guide in [`CONTRIBUTING.md`](https://github.com/TheCGO/fiscalsim-us/blob/main/CONTRIBUTING.md) for instructions on how to best collaborate with us. Please contact the `FiscalSim-US` model maintainer, [Richard W. Evans](https://sites.google.com/site/rickecon) (GitHub: [@rickecon](https://github.com/rickecon)) with any questions.
